@@ -1,4 +1,4 @@
-package App::curo::list; our $VERSION = '0.01_01';
+package App::curo::list; our $VERSION = '0.01_02';
 use strict;
 use warnings;
 use App::curo::Util;
@@ -49,15 +49,11 @@ App::curo::list - List project tasks and issues
 
 =head1 SYNOPSIS
 
-  curo list [<what>]
+  curo list [PROJECT]
 
 =head1 DESCRIPTION
 
-See L<ddb>(1) for details.
-
-=head1 SEE ALSO
-
-L<DDB::Cmd>(3p), L<ddb>(1)
+See L<curo>(1) for details.
 
 =head1 AUTHOR
 
