@@ -1,4 +1,4 @@
-package App::curo::status; our $VERSION = '0.01_01';
+package App::curo::status; our $VERSION = '0.01_02';
 use strict;
 use warnings;
 use App::curo::Util;
@@ -55,10 +55,6 @@ App::curo::status - Show project status
 
 See L<curo>(1) for details.
 
-=head1 SEE ALSO
-
-L<DDB>(3p), L<curo>(1)
-
 =head1 AUTHOR
 
 Mark Lawrence E<lt>nomad@null.netE<gt>
